@@ -55,7 +55,7 @@ class DDG(callbacks.Plugin):
 
     Example::
 
-        <+GLolol> %ddg search eiffel tower
+        <+jlu5> %ddg search eiffel tower
         <@Atlas> The Eiffel Tower is an iron lattice tower located on the Champ de Mars in Paris. It was named after the engineer Gustave Eiffel, whose company designed and built the tower. - <https://en.wikipedia.org/wiki/Eiffel_Tower>
 
     """
