@@ -28,7 +28,7 @@
 ###
 
 """
-Includes various web-related commands.
+This plugin allows you to view website information, like the title of a page. Also provides a Snarfer for URLs.
 """
 
 import supybot
