@@ -389,15 +389,15 @@ class ChannelState(utils.python.Object):
         """Returns whether the given nick is an halfop, or an op."""
         return nick in self.halfops or nick in self.ops
 
-    def addUser(self, user):
+    def addUser(self, user, prefix_chars='@%+&~!'):
         "Adds a given user to the ChannelState.  Power prefixes are handled."
-        nick = user.lstrip('@%+&~!')
+        nick = user.lstrip(prefix_chars)
         if not nick:
             return
         # & is used to denote protected users in UnrealIRCd
         # ~ is used to denote channel owner in UnrealIRCd
         # ! is used to denote protected users in UltimateIRCd
-        while user and user[0] in '@%+&~!':
+        while user and user[0] in prefix_chars:
             (marker, user) = (user[0], user[1:])
             assert user, 'Looks like my caller is passing chars, not nicks.'
             if marker in '@&~!':
@@ -708,8 +708,11 @@ class IrcState(IrcCommandDispatcher, log.Firewalled):
         self.channels = channels
         self.nicksToHostmasks = nicksToHostmasks
 
-        # Batches should always finish and be way shorter than 3600s, but
-        # let's just make sure to avoid leaking memory.
+        # Batches usually finish and are way shorter than 3600s, but
+        # we need to:
+        # * keep them in case the connection breaks (and reset() can't
+        #   clear the list itself)
+        # * make sure to avoid leaking memory in general
         self.batches = ExpiringDict(timeout=3600)
 
     def reset(self):
@@ -721,12 +724,24 @@ class IrcState(IrcCommandDispatcher, log.Firewalled):
         self.channels.clear()
         self.supported.clear()
         self.nicksToHostmasks.clear()
-        self.batches.clear()
         self.capabilities_req = set()
         self.capabilities_ack = set()
         self.capabilities_nak = set()
         self.capabilities_ls = {}
 
+        # Don't clear batches right now. reset() is called on ERROR messages,
+        # which may be part of a BATCH so we need to remember that batch.
+        # At worst, the batch will expire in the near future, as self.batches
+        # is an instance of ExpiringDict.
+        # If we did clear the batch, then this would happen:
+        # 1. IrcState.addMsg() would crash on the ERROR, because its batch
+        #    server-tag references an unknown batch, so it would not set the
+        #    'batch' supybot-tag
+        # 2. Irc.doBatch would crash on the closing BATCH, for the same reason
+        # 3. Owner.doBatch would crash because it expects the batch
+        #    supybot-tag to be set, but it wasn't because of 1
+        #self.batches.clear()
+
     def __reduce__(self):
         return (self.__class__, (self.history, self.supported,
                                  self.nicksToHostmasks, self.channels))
@@ -948,13 +963,27 @@ class IrcState(IrcCommandDispatcher, log.Firewalled):
         if channel not in self.channels:
             self.channels[channel] = ChannelState()
         c = self.channels[channel]
+
+        # Set of prefixes servers may append before a NAMES reply when
+        # the user is op/halfop/voice/...
+        # https://datatracker.ietf.org/doc/html/draft-hardy-irc-isupport-00#section-4.15
+        prefix = self.supported.get('PREFIX')
+        if prefix is None:
+            prefix_chars = '@%+&~!'  # see the comments in addUser
+        else:
+            prefix_chars = ''.join(prefix.values())
+
         for item in items.split():
-            if ircutils.isUserHostmask(item):
-                name = ircutils.nickFromHostmask(item)
-                self.nicksToHostmasks[name] = name
+            stripped_item = item.lstrip(prefix_chars)
+            item_prefix = item[0:-len(stripped_item)]
+            if ircutils.isUserHostmask(stripped_item):
+                nick = ircutils.nickFromHostmask(stripped_item)
+                self.nicksToHostmasks[nick] = stripped_item
+                name = item_prefix + nick
             else:
                 name = item
-            c.addUser(name)
+            c.addUser(name, prefix_chars=prefix_chars)
+
         if type == '@':
             c.modes['s'] = None
 
