@@ -529,6 +529,42 @@ class IrcStateTestCase(SupyTestCase):
         st = irclib.IrcState()
         self.assert_(st.addMsg(self.irc, ircmsgs.IrcMsg('MODE foo +i')) or 1)
 
+    def testNamreply(self):
+        """RPL_NAMREPLY / reply to NAMES"""
+
+        # Just nicks (à la RFC 1459 + some common prefix chars)
+        st = irclib.IrcState()
+        st.addMsg(self.irc, ircmsgs.IrcMsg(command='353',
+            args=('*', '=', '#chan', 'nick1 @nick2 ~@nick3')))
+        chan_st = st.channels['#chan']
+        self.assertEqual(chan_st.users, ircutils.IrcSet(['nick1', 'nick2', 'nick3']))
+        self.assertEqual(chan_st.ops, ircutils.IrcSet(['nick2', 'nick3']))
+        self.assertEqual(st.nicksToHostmasks, ircutils.IrcDict({}))
+
+        # with userhost-in-names
+        st = irclib.IrcState()
+        st.addMsg(self.irc, ircmsgs.IrcMsg(command='353',
+            args=('*', '=', '#chan', 'nick1!u1@h1 @nick2!u2@h2 ~@nick3!u3@h3')))
+        chan_st = st.channels['#chan']
+        self.assertEqual(chan_st.users, ircutils.IrcSet(['nick1', 'nick2', 'nick3']))
+        self.assertEqual(chan_st.ops, ircutils.IrcSet(['nick2', 'nick3']))
+        self.assertEqual(st.nicksToHostmasks['nick1'], 'nick1!u1@h1')
+        self.assertEqual(st.nicksToHostmasks['nick2'], 'nick2!u2@h2')
+        self.assertEqual(st.nicksToHostmasks['nick3'], 'nick3!u3@h3')
+
+        # Prefixed with chars not in ISUPPORT PREFIX
+        st = irclib.IrcState()
+        st.addMsg(self.irc, ircmsgs.IrcMsg(command='005',
+            args=('*', 'PREFIX=(ov)@+', 'are supported')))
+        st.addMsg(self.irc, ircmsgs.IrcMsg(command='353',
+            args=('*', '=', '#chan', 'nick1!u1@h1 @nick2!u2@h2 ~@nick3!u3@h3')))
+        chan_st = st.channels['#chan']
+        self.assertEqual(chan_st.users, ircutils.IrcSet(['nick1', 'nick2', '~@nick3']))
+        self.assertEqual(chan_st.ops, ircutils.IrcSet(['nick2']))
+        self.assertEqual(st.nicksToHostmasks['nick1'], 'nick1!u1@h1')
+        self.assertEqual(st.nicksToHostmasks['nick2'], 'nick2!u2@h2')
+        self.assertEqual(st.nicksToHostmasks['~@nick3'], '~@nick3!u3@h3')
+
 
 class IrcCapsTestCase(SupyTestCase, CapNegMixin):
     def testReqLineLength(self):
@@ -1042,8 +1078,6 @@ class IrcTestCase(SupyTestCase):
             repr(c.batch)
         )
 
-    maxDiff = None
-
     def testBatchNested(self):
         self.irc.reset()
         logs = textwrap.dedent('''
@@ -1107,6 +1141,42 @@ class IrcTestCase(SupyTestCase):
         self.assertEqual(msg5.tagged('batch'), outer)
         self.assertEqual(self.irc.state.getParentBatches(msg5), [outer])
 
+    def testBatchError(self):
+        # Checks getting an ERROR message in a batch does not cause issues
+        # due to deinitializing the connection at the same time.
+        self.irc.reset()
+        m1 = ircmsgs.IrcMsg(':host BATCH +name batchtype')
+        self.irc.feedMsg(m1)
+        m2 = ircmsgs.IrcMsg('@batch=name :someuser2 NOTICE * :oh no')
+        self.irc.feedMsg(m2)
+        m3 = ircmsgs.IrcMsg('@batch=name ERROR :bye')
+        self.irc.feedMsg(m3)
+        class Callback(irclib.IrcCallback):
+            batch = None
+            def __call__(self, *args, **kwargs):
+                return super().__call__(*args, **kwargs)
+            def name(self):
+                return 'testcallback'
+            def doBatch(self2, irc, msg):
+                self2.batch = msg.tagged('batch')
+
+        # would usually be called by the driver upon reconnect() trigged
+        # by the ERROR:
+        self.irc.reset()
+
+        c = Callback()
+        self.irc.addCallback(c)
+        try:
+            m4 = ircmsgs.IrcMsg(':host BATCH -name')
+            self.irc.feedMsg(m4)
+        finally:
+            self.irc.removeCallback(c.name())
+        self.assertEqual(
+            c.batch,
+            irclib.Batch('name', 'batchtype', (), [m1, m2, m3, m4], None),
+            repr(c.batch)
+        )
+
     def testTruncate(self):
         self.irc = irclib.Irc('test')
 
