@@ -113,6 +113,24 @@ class FunctionsTestCase(SupyTestCase):
         self.assertFalse(ircutils.isUserHostmask('@'))
         self.assertFalse(ircutils.isUserHostmask('!bar@baz'))
 
+    def testSplitHostmask(self):
+        # This is the only valid case:
+        self.assertEqual(ircutils.splitHostmask('foo!bar@baz'),
+            ('foo', 'bar', 'baz'))
+
+        # This ones are technically allowed by RFC1459, but never happens in
+        # practice:
+        self.assertEqual(ircutils.splitHostmask('foo!bar!qux@quux'),
+            ('foo', 'bar!qux', 'quux'))
+        self.assertEqual(ircutils.splitHostmask('foo!bar@baz@quux'),
+            ('foo', 'bar@baz', 'quux'))
+        self.assertEqual(ircutils.splitHostmask('foo!bar@baz!qux@quux'),
+            ('foo', 'bar@baz!qux', 'quux'))
+
+        # And this one in garbage, let's just make sure we don't crash:
+        self.assertEqual(ircutils.splitHostmask('foo!bar@baz!qux'),
+            ('foo', 'bar', 'baz!qux'))
+
     def testIsChannel(self):
         self.assertTrue(ircutils.isChannel('#'))
         self.assertTrue(ircutils.isChannel('&'))
